.. koala documentation master file, created by
   sphinx-quickstart on Thu Feb 13 16:10:23 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pykoala's documentation!
=================================


PyKOALA is an innovative Python-based library designed to provide a robust and flexible framework for Integral Field Spectroscopy (IFS) data reduction.

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    installation/index
    user-guide/index
    api/api
    contributing/index
    license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
